# -*- coding: utf-8 -*-

VERSION = "3.34.1"
PACKAGE = "gedit-plugins"
PACKAGE_STRING = "gedit-plugins-3.14"
GETTEXT_PACKAGE = "gedit-plugins"
GP_LOCALEDIR = "/usr/local/share/locale"
